esdoc-py-client
===============

Python client for the esdoc eco-system, more commonly referred to as pyesdoc.


What is ES-DOC ?
--------------------------------------

ES-DOC stands for Earth Science - Documentation.  It's goal is to provide software tools and services in order to support the distribution of earth science documentation.


What is pyesdoc ?
--------------------------------------

pyesdoc is a python client library for exploiting the ES-DOC eco-system.  It supports documentation creation, validation, serialization, publishing, I/O & search use cases.


Why pyesdoc ?
--------------------------------------

A documentation eco-system is only as good as the available client tools.  ES-DOC provides the pyesdoc client tool so as to simplify leveraging the ES-DOC eco-ssytem in the python programming language.


Who uses pyesdoc ?
--------------------------------------

Developers building value added software ontop of the ES-DOC eco-system.


Further Information ?
--------------------------------------

See http:es-doc.org.